gs_quant.timeseries.econometrics.annualize — gs_quant 0.1 documentation

# gs_quant.timeseries.econometrics.annualize

`annualize`(x)

  Annualize series based on sample observation frequency

  Parameters

    x (`Series`) – time series of prices

  Return type

    `Series`

  Returns

    date-based time series of annualized values

  Usage

  Based on number of days between observations, will determine an annualization factor and then adjust values accordingly. Useful for annualizing daily or monthly returns

  \(Y_t = X_t * \sqrt{F}\)

  Annualization factors as follows, based on period implied by observations:

  Period | Annualization Factor (F)
  --- | ---
  Daily | \(252\)
  Weekly | \(52\)
  Bi-Weekly | \(26\)
  Monthly | \(12\)
  Quarterly | \(4\)
  Annually | \(1\)

  Examples

  Annualize daily returns series:

      >>> prices = generate_series(100)
      >>> ann = annualize(returns(prices))

  See also

  `returns()`